@@ -4,15 +4,15 @@ from __future__ import annotations
 from enum import Enum
 from typing import Any, TypeVar
 
-_StrEnumT = TypeVar("_StrEnumT", bound="StrEnum")
+_StrEnumSelfT = TypeVar("_StrEnumSelfT", bound="StrEnum")
 
 
 class StrEnum(str, Enum):
     """Partial backport of Python 3.11's StrEnum for our basic use cases."""
 
     def __new__(
-        cls: type[_StrEnumT], value: str, *args: Any, **kwargs: Any
-    ) -> _StrEnumT:
+        cls: type[_StrEnumSelfT], value: str, *args: Any, **kwargs: Any
+    ) -> _StrEnumSelfT:
         """Create a new StrEnum instance."""
         if not isinstance(value, str):
             raise TypeError(f"{value!r} is not a string")
